@@ -24,25 +24,17 @@ cmultRepl <- function(X,label=0,method=c("GBM","SQ","BL","CZM","user"),output=c(
   X[X==label] <- NA
   
   checkNumZerosCol <- apply(X,2,function(x) sum(is.na(x)))
-  if (any(checkNumZerosCol/nrow(X) == 1)) {
-    stop(paste("Column(s) containing all zeros/unobserved values were found (check it out using zPatterns).",sep=""))
+  if (any(checkNumZerosCol/nrow(X) >= z.warning)) {
+    cases <- which(checkNumZerosCol/nrow(X) >= z.warning)
+    X <- X[,-cases]
+    warning(paste("Column ",cases," containing more than ",z.warning*100,"% zeros/unobserved values was deleted (pre-check out using function zPatterns/modify threshold using argument z.warning).\n",sep=""))
   }
-  else{
-    if (any(checkNumZerosCol/nrow(X) > z.warning)) {
-      warning(paste("Column(s) containing more than ",z.warning*100,"% zeros/unobserved values were found (check it out using zPatterns).
-                    (You can use the z.warning argument to modify the warning threshold).",sep=""))
-    }
-  }
-
+  
   checkNumZerosRow <- apply(X,1,function(x) sum(is.na(x)))
-  if (any(checkNumZerosRow/ncol(X) == 1)) {
-    stop(paste("Row(s) containing all zeros/unobserved values were found (check it out using zPatterns).",sep=""))
-  }
-  else{
-    if (any(checkNumZerosRow/ncol(X) > z.warning)) {
-      warning(paste("Row(s) containing more than ",z.warning*100,"% zeros/unobserved values were found (check it out using zPatterns).
-                  (You can use the z.warning argument to modify the warning threshold).",sep=""))
-    }
+  if (any(checkNumZerosRow/ncol(X) >= z.warning)) {
+    cases <- which(checkNumZerosRow/ncol(X) >= z.warning)
+    X <- X[-cases,]
+    warning(paste("Row ",cases," containing more than ",z.warning*100,"% zeros/unobserved values was deleted (pre-check out using function zPatterns/modify threshold using argument z.warning).\n",sep=""))
   }
   
   N <- nrow(X); D <- ncol(X)
